orsim package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   orsim.core
   orsim.messenger
   orsim.tasks
   orsim.utils

Submodules
----------

orsim.celery\_config module
---------------------------

.. automodule:: orsim.celery_config
   :members:
   :undoc-members:
   :show-inheritance:

orsim.worker module
-------------------

.. automodule:: orsim.worker
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: orsim
   :members:
   :undoc-members:
   :show-inheritance:
